@@ -240,6 +240,10 @@ class  roadrunnerApp(hildon.Program):
                    import_data.import_csvfile(localfile, self.pb)
                 elif localfile.endswith("asc"):
                    import_data.import_csvfile(localfile, self.pb)
+                elif localfile.endswith("kml"):
+                   import_data.import_kmlfile(localfile, self.pb)
+                elif localfile.endswith("kmz"):
+                   import_data.import_kmzfile(localfile, self.pb)
                 else:
                     self.warning_message("Unknown format\nCheck file extension")
             except Exception, err:
