@@ -196,7 +196,7 @@ def import_kmlfile(kmlfile, pb):
     coordinates_iter = root.getiterator(root.tag[:-3] + 'coordinates')
     for coordinates in coordinates_iter:
         print coordinates.text
-        lat, long, alt = coordinates.text.split(',')
+        long, lat, alt = coordinates.text.split(',')
         mydb.insert_radar(lat, long, i)
         progress_status+=import_step
         i+=1
